@@ -1,5 +1,11 @@
+{-# LANGUAGE CPP #-}
+
 import Distribution.PackageDescription (package, packageDescription)
+#if __GLASGOW_HASKELL__ < 904
 import Distribution.PackageDescription.Parsec (readGenericPackageDescription)
+#else
+import Distribution.Simple.PackageDescription (readGenericPackageDescription)
+#endif
 import Distribution.Pretty (prettyShow)
 import Distribution.Types.PackageId (PackageIdentifier, pkgVersion)
 import Distribution.Verbosity (silent)
