@@ -735,7 +735,10 @@ sub configure_recipe {
 =cut
 
 sub build_recipe {
-    my () = @_;
+    my %params = (
+        parallel => 0,
+        @_
+    );
 
     croak encode_utf8('No Setup.hs executable named.')
       unless length $ENV{DEB_SETUP_BIN_NAME};
@@ -744,7 +747,11 @@ sub build_recipe {
     die encode_utf8('No Haskell compiler.')
       unless length $compiler;
 
-    doit($ENV{DEB_SETUP_BIN_NAME}, 'build', "--builddir=dist-$compiler");
+    my @args = ($ENV{DEB_SETUP_BIN_NAME}, 'build', "--builddir=dist-$compiler");
+    if ($params{parallel}) {
+        push(@args, "--jobs=$params{parallel}");
+    }
+    doit(@args);
 
     return;
 }
